<?php
/**
 * An interface for connection helper classes
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2015 Hub Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 * @todo		Please find another name for this interface
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
interface ConnectionHelper extends HubHelper {
	/**
	 * Sends raw package data to the recipient
	 *
	 * @param	$packageData		Raw package data
	 * @return	void
	 * @throws	InvalidSocketException	If we got a problem with this socket
	 */
	function sendRawPackageData (array $packageData);

	/**
	 * Do the shutdown sequence for this connection helper
	 *
	 * @todo	We may want to implement a filter for ease notification of other objects like our pool
	 * @return	void
	 * @throws	SocketShutdownException		If the current socket could not be shut down
	 */
	function doShutdown ();

	/**
	 * Getter for port number to satify HandleableProtocol
	 *
	 * @return	$port	The port number
	 */
	function getConnectionPort ();

	/**
	 * Getter for connection type
	 *
	 * @return	$type	Type of connection
	 */
	function getConnectionType ();

	/**
	 * Getter for IP address
	 *
	 * @return	$address	The IP address
	 */
	function getAddress ();

	/**
	 * Static "getter" for this connection class' name
	 *
	 * @param	$address	IP address
	 * @param	$port		Port number
	 * @param	$className	Original class name
	 * @return	$class		Expanded class name
	 */
	static function getConnectionClassName ($address, $port, $className);

	/**
	 * Getter for shuttedDown
	 *
	 * @return	$shuttedDown	Whether this connection is shutted down
	 */
	function isShuttedDown ();
}

// [EOF]
?>
