<?php
/**
 * A Initialization filter for miners
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2014 Miner Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class MinerInitializationFilter extends BaseMinerFilter implements Filterable {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Creates an instance of this filter class
	 *
	 * @return	$filterInstance		An instance of this filter class
	 */
	public static final function createMinerInitializationFilter () {
		// Get a new instance
		$filterInstance = new MinerInitializationFilter();

		// Return the instance
		return $filterInstance;
	}

	/**
	 * Executes the filter with given request and response objects
	 *
	 * @param	$requestInstance	An instance of a class with an Requestable interface
	 * @param	$responseInstance	An instance of a class with an Responseable interface
	 * @return	void
	 * @todo	0% done
	 */
	public function execute (Requestable $requestInstance, Responseable $responseInstance) {
		// The default miner-mode is from our configuration
		$minerMode = $this->getConfigInstance()->getConfigEntry('miner_default_mode');

		// Is the miner 'mode' parameter set?
		if ($requestInstance->isRequestElementSet('mode')) {
			// Then use this which overrides the config entry temporarily
			$minerMode = $requestInstance->getRequestElement('mode');
		} else {
			// Set it for easier re-usage
			$requestInstance->setRequestElement('mode', $minerMode);
		}

		// Now convert the miner-mode in a class name
		$className = 'Hub' . $this->convertToClassName($minerMode) . 'Miner';

		// And try to instance it
		try {
			// Get an instance
			$minerInstance = ObjectFactory::createObjectByName($className);

			// Get a registry
			$applicationInstance = Registry::getRegistry()->getInstance('app');

			// Set the app instance
			$minerInstance->setApplicationInstance($applicationInstance);

			// Add miner-specific filters
			$minerInstance->addExtraFilters($applicationInstance->getControllerInstance(), $responseInstance);
		} catch (ClassNotFoundException $e) {
			// This exception means, the miner mode is invalid.
			// @TODO Can we rewrite this to app_exit() ?
			$this->debugBackTrace('[' . __METHOD__ . ':' . __LINE__ . ']:  miner mode ' . $minerMode . ' is invalid.');
		}
	}
}

// [EOF]
?>
